# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/events.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/content/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.content import fragment_pb2 as eolymp_dot_content_dot_fragment__pb2
from eolymp.content import variant_pb2 as eolymp_dot_content_dot_variant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/content/events.proto\x12\x0e\x65olymp.content\x1a\x1d\x65olymp/content/fragment.proto\x1a\x1c\x65olymp/content/variant.proto\"x\n\x14\x46ragmentChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.content.Fragment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.content.Fragment\"{\n\x13VariantChangedEvent\x12\x13\n\x0b\x66ragment_id\x18\n \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.content.Variant\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.content.VariantB1Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_start=108
  _globals['_FRAGMENTCHANGEDEVENT']._serialized_end=228
  _globals['_VARIANTCHANGEDEVENT']._serialized_start=230
  _globals['_VARIANTCHANGEDEVENT']._serialized_end=353
# @@protoc_insertion_point(module_scope)
