# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/configuration.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/configuration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/discussion/configuration.proto\x12\x11\x65olymp.discussion\"\xf1\x02\n\rConfiguration\x12 \n\x18members_can_create_posts\x18\x01 \x01(\x08\x12$\n\x1cmembers_can_comment_on_posts\x18\x02 \x01(\x08\x12\'\n\x1fmembers_can_comment_on_problems\x18\x03 \x01(\x08\x12\x44\n\x0fpost_moderation\x18\x04 \x01(\x0e\x32+.eolymp.discussion.Configuration.Moderation\x12G\n\x12\x63omment_moderation\x18\x05 \x01(\x0e\x32+.eolymp.discussion.Configuration.Moderation\"`\n\nModeration\x12\x16\n\x12UNKNOWN_MODERATION\x10\x00\x12\x11\n\rNO_MODERATION\x10\x01\x12\x12\n\x0ePRE_MODERATION\x10\x02\x12\x13\n\x0fPOST_MODERATION\x10\x03\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.configuration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_CONFIGURATION']._serialized_start=61
  _globals['_CONFIGURATION']._serialized_end=430
  _globals['_CONFIGURATION_MODERATION']._serialized_start=334
  _globals['_CONFIGURATION_MODERATION']._serialized_end=430
# @@protoc_insertion_point(module_scope)
