# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/score_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/score_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/judge/score_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/judge/result.proto\x1a\x18\x65olymp/judge/score.proto\"\'\n\x11RebuildScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\")\n\x12RebuildScoreOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\"*\n\x14IntrospectScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\";\n\x15IntrospectScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"m\n\x0fWatchScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x04mode\x18\x03 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\"6\n\x10WatchScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"\x85\x01\n\x12\x44\x65scribeScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x04mode\x18\x03 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x04 \x01(\x05\"9\n\x13\x44\x65scribeScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"c\n\x10ImportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x13\n\x11ImportScoreOutput\">\n\x10\x45xportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"8\n\x11\x45xportScoreOutput\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x88\x01\n\x0fListResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x10ListResultOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Result\"l\n\x11\x45xportResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\"(\n\x12\x45xportResultOutput\x12\x12\n\nexport_url\x18\x01 \x01(\t2\xb3\t\n\x0cScoreService\x12\x84\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x13\x12\x11/introspect/score\x12i\n\nWatchScore\x12\x1d.eolymp.judge.WatchScoreInput\x1a\x1e.eolymp.judge.WatchScoreOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xac\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"V\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02&\x12$/participants/{participant_id}/score\x12\xa7\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"W\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\'\"%/participants/{participant_id}/scores\x12\xa7\x01\n\x0b\x45xportScore\x12\x1e.eolymp.judge.ExportScoreInput\x1a\x1f.eolymp.judge.ExportScoreOutput\"W\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\'\x12%/participants/{participant_id}/scores\x12\x87\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\":\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\n\x12\x08/results\x12\x93\x01\n\x0c\x45xportResult\x12\x1f.eolymp.judge.ExportResultInput\x1a .eolymp.judge.ExportResultOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x11\"\x0f/results-export\x12\x8d\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\n\"\x08/rebuildB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.score_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SCORESERVICE'].methods_by_name['IntrospectScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\023\022\021/introspect/score'
  _globals['_SCORESERVICE'].methods_by_name['WatchScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['WatchScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_SCORESERVICE'].methods_by_name['DescribeScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['DescribeScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002&\022$/participants/{participant_id}/score'
  _globals['_SCORESERVICE'].methods_by_name['ImportScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ImportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\'\"%/participants/{participant_id}/scores'
  _globals['_SCORESERVICE'].methods_by_name['ExportScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ExportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\'\022%/participants/{participant_id}/scores'
  _globals['_SCORESERVICE'].methods_by_name['ListResult']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ListResult']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\n\022\010/results'
  _globals['_SCORESERVICE'].methods_by_name['ExportResult']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['ExportResult']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\021\"\017/results-export'
  _globals['_SCORESERVICE'].methods_by_name['RebuildScore']._loaded_options = None
  _globals['_SCORESERVICE'].methods_by_name['RebuildScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\n\"\010/rebuild'
  _globals['_REBUILDSCOREINPUT']._serialized_start=202
  _globals['_REBUILDSCOREINPUT']._serialized_end=241
  _globals['_REBUILDSCOREOUTPUT']._serialized_start=243
  _globals['_REBUILDSCOREOUTPUT']._serialized_end=284
  _globals['_INTROSPECTSCOREINPUT']._serialized_start=286
  _globals['_INTROSPECTSCOREINPUT']._serialized_end=328
  _globals['_INTROSPECTSCOREOUTPUT']._serialized_start=330
  _globals['_INTROSPECTSCOREOUTPUT']._serialized_end=389
  _globals['_WATCHSCOREINPUT']._serialized_start=391
  _globals['_WATCHSCOREINPUT']._serialized_end=500
  _globals['_WATCHSCOREOUTPUT']._serialized_start=502
  _globals['_WATCHSCOREOUTPUT']._serialized_end=556
  _globals['_DESCRIBESCOREINPUT']._serialized_start=559
  _globals['_DESCRIBESCOREINPUT']._serialized_end=692
  _globals['_DESCRIBESCOREOUTPUT']._serialized_start=694
  _globals['_DESCRIBESCOREOUTPUT']._serialized_end=751
  _globals['_IMPORTSCOREINPUT']._serialized_start=753
  _globals['_IMPORTSCOREINPUT']._serialized_end=852
  _globals['_IMPORTSCOREOUTPUT']._serialized_start=854
  _globals['_IMPORTSCOREOUTPUT']._serialized_end=873
  _globals['_EXPORTSCOREINPUT']._serialized_start=875
  _globals['_EXPORTSCOREINPUT']._serialized_end=937
  _globals['_EXPORTSCOREOUTPUT']._serialized_start=939
  _globals['_EXPORTSCOREOUTPUT']._serialized_end=995
  _globals['_LISTRESULTINPUT']._serialized_start=998
  _globals['_LISTRESULTINPUT']._serialized_end=1134
  _globals['_LISTRESULTOUTPUT']._serialized_start=1136
  _globals['_LISTRESULTOUTPUT']._serialized_end=1206
  _globals['_EXPORTRESULTINPUT']._serialized_start=1208
  _globals['_EXPORTRESULTINPUT']._serialized_end=1316
  _globals['_EXPORTRESULTOUTPUT']._serialized_start=1318
  _globals['_EXPORTRESULTOUTPUT']._serialized_end=1358
  _globals['_SCORESERVICE']._serialized_start=1361
  _globals['_SCORESERVICE']._serialized_end=2564
# @@protoc_insertion_point(module_scope)
