# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/solution.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/solution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/solution.proto\x12\x0c\x65olymp.atlas\"\xbb\x03\n\x08Solution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\x08\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12)\n\x04type\x18\x14 \x01(\x0e\x32\x1b.eolymp.atlas.Solution.Type\x12-\n\x06status\x18\x1e \x01(\x0e\x32\x1d.eolymp.atlas.Solution.Status\x12\x15\n\rsubmission_id\x18\x1f \x01(\t\"\xa8\x01\n\x04Type\x12\t\n\x05UNSET\x10\x00\x12\x0b\n\x07\x43ORRECT\x10\x01\x12\r\n\tINCORRECT\x10\x02\x12\x10\n\x0cWRONG_ANSWER\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08OVERFLOW\x10\x05\x12\x17\n\x13TIMEOUT_OR_ACCEPTED\x10\x06\x12\x18\n\x14OVERFLOW_OR_ACCEPTED\x10\x07\x12\x0c\n\x08\x44ONT_RUN\x10\x08\x12\x0b\n\x07\x46\x41ILURE\x10\t\"H\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\t\x12\x08\n\x04PASS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SOLUTION']._serialized_start=46
  _globals['_SOLUTION']._serialized_end=489
  _globals['_SOLUTION_TYPE']._serialized_start=247
  _globals['_SOLUTION_TYPE']._serialized_end=415
  _globals['_SOLUTION_STATUS']._serialized_start=417
  _globals['_SOLUTION_STATUS']._serialized_end=489
# @@protoc_insertion_point(module_scope)
