# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/newsletter/campaign.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/newsletter/campaign.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/newsletter/campaign.proto\x12\x11\x65olymp.newsletter\x1a!eolymp/community/email_type.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x04\n\x08\x43\x61mpaign\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.eolymp.community.EmailType\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07subject\x18\x0b \x01(\t\x12$\n\x07\x63ontent\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x18\n\x10recipients_count\x18\x1e \x01(\r\x12\x15\n\rpending_count\x18\x1f \x01(\r\x12\x12\n\nsent_count\x18  \x01(\r\x12\x13\n\x0b\x65rror_count\x18! \x01(\r\x1as\n\x0bTranslation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x66 \x01(\t\x12\x0f\n\x07subject\x18g \x01(\t\x12$\n\x07\x63ontent\x18h \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x11\n\tautomatic\x18i \x01(\x08\"J\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04TYPE\x10\x01\x12\x08\n\x04NAME\x10\x05\x12\x0b\n\x07SUBJECT\x10\x02\x12\x0b\n\x07\x43ONTENT\x10\x03\x12\n\n\x06LOCALE\x10\x04\"A\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x11\n\rCONTENT_VALUE\x10\x01\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x02\x42\x37Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.campaign_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _globals['_CAMPAIGN']._serialized_start=150
  _globals['_CAMPAIGN']._serialized_end=682
  _globals['_CAMPAIGN_TRANSLATION']._serialized_start=424
  _globals['_CAMPAIGN_TRANSLATION']._serialized_end=539
  _globals['_CAMPAIGN_PATCH']._serialized_start=541
  _globals['_CAMPAIGN_PATCH']._serialized_end=615
  _globals['_CAMPAIGN_EXTRA']._serialized_start=617
  _globals['_CAMPAIGN_EXTRA']._serialized_end=682
# @@protoc_insertion_point(module_scope)
