# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/course.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/course/course.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/course.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"\xfe\x02\n\x06\x43ourse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12(\n\x0b\x64\x65scription\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x11\n\timage_url\x18\r \x01(\t\x12\x34\n\nvisibility\x18\x0e \x01(\x0e\x32 .eolymp.course.Course.Visibility\x12\x10\n\x08\x64uration\x18\x0f \x01(\r\x12\x0e\n\x06topics\x18\x10 \x03(\t\x12\x10\n\x08\x65stimate\x18\x14 \x01(\r\"I\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\"K\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08UNLISTED\x10\x02\x12\x0b\n\x07PRIVATE\x10\x03\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.course_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_COURSE']._serialized_start=72
  _globals['_COURSE']._serialized_end=454
  _globals['_COURSE_EXTRA']._serialized_start=304
  _globals['_COURSE_EXTRA']._serialized_end=377
  _globals['_COURSE_VISIBILITY']._serialized_start=379
  _globals['_COURSE_VISIBILITY']._serialized_end=454
# @@protoc_insertion_point(module_scope)
