# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/stats.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/executor/stats.proto\x12\x0f\x65olymp.executor\"\xb1\x01\n\x05Stats\x12\x11\n\tstdin_url\x18\x01 \x01(\t\x12\x12\n\nstdout_url\x18\x02 \x01(\t\x12\x12\n\nstderr_url\x18\x03 \x01(\t\x12\x1a\n\x12wall_time_duration\x18\x14 \x01(\r\x12\x19\n\x11\x63pu_time_duration\x18\x19 \x01(\r\x12\x13\n\x0bmemory_peak\x18\x1e \x01(\x04\x12\x0e\n\x06signal\x18\x65 \x01(\r\x12\x11\n\texit_code\x18\x64 \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_STATS']._serialized_start=49
  _globals['_STATS']._serialized_end=226
# @@protoc_insertion_point(module_scope)
