# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/configuration_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/configuration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.discussion import configuration_pb2 as eolymp_dot_discussion_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/discussion/configuration_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/discussion/configuration.proto\"\x1f\n\x1d\x44\x65scribeDiscussionConfigInput\"R\n\x1e\x44\x65scribeDiscussionConfigOutput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.discussion.Configuration\"\xf4\x01\n\x1bUpdateDiscussionConfigInput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.discussion.Configuration\"\xa2\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x1c\n\x18MEMBERS_CAN_CREATE_POSTS\x10\x01\x12 \n\x1cMEMBERS_CAN_COMMENT_ON_POSTS\x10\x02\x12#\n\x1fMEMBERS_CAN_COMMENT_ON_PROBLEMS\x10\x03\x12\x13\n\x0fPOST_MODERATION\x10\x04\x12\x16\n\x12\x43OMMENT_MODERATION\x10\x05\"\x1e\n\x1cUpdateDiscussionConfigOutput2\xee\x02\n\x14\x43onfigurationService\x12\xac\x01\n\x18\x44\x65scribeDiscussionConfig\x12\x30.eolymp.discussion.DescribeDiscussionConfigInput\x1a\x31.eolymp.discussion.DescribeDiscussionConfigOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/configs/discussions\x12\xa6\x01\n\x16UpdateDiscussionConfig\x12..eolymp.discussion.UpdateDiscussionConfigInput\x1a/.eolymp.discussion.UpdateDiscussionConfigOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/configs/discussionsB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.configuration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeDiscussionConfig']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeDiscussionConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\022\024/configs/discussions'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['UpdateDiscussionConfig']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['UpdateDiscussionConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/configs/discussions'
  _globals['_DESCRIBEDISCUSSIONCONFIGINPUT']._serialized_start=174
  _globals['_DESCRIBEDISCUSSIONCONFIGINPUT']._serialized_end=205
  _globals['_DESCRIBEDISCUSSIONCONFIGOUTPUT']._serialized_start=207
  _globals['_DESCRIBEDISCUSSIONCONFIGOUTPUT']._serialized_end=289
  _globals['_UPDATEDISCUSSIONCONFIGINPUT']._serialized_start=292
  _globals['_UPDATEDISCUSSIONCONFIGINPUT']._serialized_end=536
  _globals['_UPDATEDISCUSSIONCONFIGINPUT_PATCH']._serialized_start=374
  _globals['_UPDATEDISCUSSIONCONFIGINPUT_PATCH']._serialized_end=536
  _globals['_UPDATEDISCUSSIONCONFIGOUTPUT']._serialized_start=538
  _globals['_UPDATEDISCUSSIONCONFIGOUTPUT']._serialized_end=568
  _globals['_CONFIGURATIONSERVICE']._serialized_start=571
  _globals['_CONFIGURATIONSERVICE']._serialized_end=937
# @@protoc_insertion_point(module_scope)
