# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/newsletter/campaign_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/newsletter/campaign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.newsletter import campaign_pb2 as eolymp_dot_newsletter_dot_campaign__pb2
from eolymp.newsletter import recipient_pb2 as eolymp_dot_newsletter_dot_recipient__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/newsletter/campaign_service.proto\x12\x11\x65olymp.newsletter\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/newsletter/campaign.proto\x1a!eolymp/newsletter/recipient.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"D\n\x13\x43reateCampaignInput\x12-\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"+\n\x14\x43reateCampaignOutput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x8b\x01\n\x13UpdateCampaignInput\x12\x30\n\x05patch\x18\x01 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Patch\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12-\n\x08\x63\x61mpaign\x18\x03 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\x16\n\x14UpdateCampaignOutput\"*\n\x13\x44\x65leteCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteCampaignOutput\"_\n\x15\x44\x65scribeCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Extra\"G\n\x16\x44\x65scribeCampaignOutput\x12-\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\xa9\x03\n\x12ListCampaignsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.newsletter.ListCampaignsInput.Filter\x12\x0e\n\x06search\x18) \x01(\t\x12\x38\n\x04sort\x18\x32 \x01(\x0e\x32*.eolymp.newsletter.ListCampaignsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Extra\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x16\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\"P\n\x13ListCampaignsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\xd7\x01\n\x11TestCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12H\n\nparameters\x18\x14 \x03(\x0b\x32\x34.eolymp.newsletter.TestCampaignInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x14\n\x12TestCampaignOutput\">\n\x11SendCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x14\n\x12SendCampaignOutput\"\x80\x01\n\x16TranslateCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\")\n\x17TranslateCampaignOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"k\n\x16\x43reateTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12<\n\x0btranslation\x18\x02 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"1\n\x17\x43reateTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xb5\x01\n\x16UpdateTranslationInput\x12\x30\n\x05patch\x18\x01 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Patch\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12<\n\x0btranslation\x18\x04 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\x19\n\x17UpdateTranslationOutput\"E\n\x16\x44\x65leteTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"G\n\x18\x44\x65scribeTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"Y\n\x19\x44\x65scribeTranslationOutput\x12<\n\x0btranslation\x18\x01 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\xf4\x01\n\x15ListTranslationsInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12@\n\x07\x66ilters\x18( \x01(\x0b\x32/.eolymp.newsletter.ListTranslationsInput.Filter\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"_\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\xbe\x01\n\x14\x43reateRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x0b \x01(\t\x12K\n\nparameters\x18\x14 \x03(\x0b\x32\x37.eolymp.newsletter.CreateRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"\xf6\x01\n\x14ImportRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x15\n\x0b\x61ll_members\x18\n \x01(\x08H\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12\x14\n\ncontest_id\x18\x0c \x01(\tH\x00\x12K\n\nparameters\x18\x14 \x03(\x0b\x32\x37.eolymp.newsletter.ImportRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"\x17\n\x15ImportRecipientOutput\"A\n\x14\x44\x65leteRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRecipientOutput\"\xa4\x02\n\x13ListRecipientsInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.newsletter.ListRecipientsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tmember_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"R\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.newsletter.Recipient\"C\n\x16\x44\x65scribeRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"J\n\x17\x44\x65scribeRecipientOutput\x12/\n\trecipient\x18\x01 \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient2\xc5\x1b\n\x0f\x43\x61mpaignService\x12\xa7\x01\n\x0e\x43reateCampaign\x12&.eolymp.newsletter.CreateCampaignInput\x1a\'.eolymp.newsletter.CreateCampaignOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x0c\"\n/campaigns\x12\xb5\x01\n\x0eUpdateCampaign\x12&.eolymp.newsletter.UpdateCampaignInput\x1a\'.eolymp.newsletter.UpdateCampaignOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1a\x1a\x18/campaigns/{campaign_id}\x12\xb5\x01\n\x0e\x44\x65leteCampaign\x12&.eolymp.newsletter.DeleteCampaignInput\x1a\'.eolymp.newsletter.DeleteCampaignOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1a*\x18/campaigns/{campaign_id}\x12\x99\x01\n\x10\x44\x65scribeCampaign\x12(.eolymp.newsletter.DescribeCampaignInput\x1a).eolymp.newsletter.DescribeCampaignOutput\"0\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1a\x12\x18/campaigns/{campaign_id}\x12\x81\x01\n\rListCampaigns\x12%.eolymp.newsletter.ListCampaignsInput\x1a&.eolymp.newsletter.ListCampaignsOutput\"!\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/campaigns\x12\xb4\x01\n\x0cTestCampaign\x12$.eolymp.newsletter.TestCampaignInput\x1a%.eolymp.newsletter.TestCampaignOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/campaigns/{campaign_id}/test\x12\xb4\x01\n\x0cSendCampaign\x12$.eolymp.newsletter.SendCampaignInput\x1a%.eolymp.newsletter.SendCampaignOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/campaigns/{campaign_id}/send\x12\xc8\x01\n\x11TranslateCampaign\x12).eolymp.newsletter.TranslateCampaignInput\x1a*.eolymp.newsletter.TranslateCampaignOutput\"\\\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02$\"\"/campaigns/{campaign_id}/translate\x12\xcb\x01\n\x11\x43reateTranslation\x12).eolymp.newsletter.CreateTranslationInput\x1a*.eolymp.newsletter.CreateTranslationOutput\"_\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\'\"%/campaigns/{campaign_id}/translations\x12\xdc\x01\n\x11UpdateTranslation\x12).eolymp.newsletter.UpdateTranslationInput\x1a*.eolymp.newsletter.UpdateTranslationOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38\x1a\x36/campaigns/{campaign_id}/translations/{translation_id}\x12\xdc\x01\n\x11\x44\x65leteTranslation\x12).eolymp.newsletter.DeleteTranslationInput\x1a*.eolymp.newsletter.DeleteTranslationOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38*6/campaigns/{campaign_id}/translations/{translation_id}\x12\xe2\x01\n\x13\x44\x65scribeTranslation\x12+.eolymp.newsletter.DescribeTranslationInput\x1a,.eolymp.newsletter.DescribeTranslationOutput\"p\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02\x38\x12\x36/campaigns/{campaign_id}/translations/{translation_id}\x12\xc7\x01\n\x10ListTranslations\x12(.eolymp.newsletter.ListTranslationsInput\x1a).eolymp.newsletter.ListTranslationsOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02\'\x12%/campaigns/{campaign_id}/translations\x12\xc3\x01\n\x0f\x43reateRecipient\x12\'.eolymp.newsletter.CreateRecipientInput\x1a(.eolymp.newsletter.CreateRecipientOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02%\"#/campaigns/{campaign_id}/recipients\x12\xca\x01\n\x0fImportRecipient\x12\'.eolymp.newsletter.ImportRecipientInput\x1a(.eolymp.newsletter.ImportRecipientOutput\"d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02,\"*/campaigns/{campaign_id}/recipients:import\x12\xd2\x01\n\x0f\x44\x65leteRecipient\x12\'.eolymp.newsletter.DeleteRecipientInput\x1a(.eolymp.newsletter.DeleteRecipientOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x34*2/campaigns/{campaign_id}/recipients/{recipient_id}\x12\xc0\x01\n\x0eListRecipients\x12&.eolymp.newsletter.ListRecipientsInput\x1a\'.eolymp.newsletter.ListRecipientsOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02%\x12#/campaigns/{campaign_id}/recipients\x12\xd8\x01\n\x11\x44\x65scribeRecipient\x12).eolymp.newsletter.DescribeRecipientInput\x1a*.eolymp.newsletter.DescribeRecipientOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x34\x12\x32/campaigns/{campaign_id}/recipients/{recipient_id}B7Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.campaign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\014\"\n/campaigns'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\032\032\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\032*\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeCampaign']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\032\022\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListCampaigns']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListCampaigns']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/campaigns'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TestCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TestCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\037\"\035/campaigns/{campaign_id}/test'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['SendCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['SendCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\037\"\035/campaigns/{campaign_id}/send'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TranslateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TranslateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002$\"\"/campaigns/{campaign_id}/translate'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\'\"%/campaigns/{campaign_id}/translations'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028\0326/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028*6/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\0028\0226/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListTranslations']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002\'\022%/campaigns/{campaign_id}/translations'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002%\"#/campaigns/{campaign_id}/recipients'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ImportRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ImportRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002,\"*/campaigns/{campaign_id}/recipients:import'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0024*2/campaigns/{campaign_id}/recipients/{recipient_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListRecipients']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListRecipients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002%\022#/campaigns/{campaign_id}/recipients'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0024\0222/campaigns/{campaign_id}/recipients/{recipient_id}'
  _globals['_CREATECAMPAIGNINPUT']._serialized_start=300
  _globals['_CREATECAMPAIGNINPUT']._serialized_end=368
  _globals['_CREATECAMPAIGNOUTPUT']._serialized_start=370
  _globals['_CREATECAMPAIGNOUTPUT']._serialized_end=413
  _globals['_UPDATECAMPAIGNINPUT']._serialized_start=416
  _globals['_UPDATECAMPAIGNINPUT']._serialized_end=555
  _globals['_UPDATECAMPAIGNOUTPUT']._serialized_start=557
  _globals['_UPDATECAMPAIGNOUTPUT']._serialized_end=579
  _globals['_DELETECAMPAIGNINPUT']._serialized_start=581
  _globals['_DELETECAMPAIGNINPUT']._serialized_end=623
  _globals['_DELETECAMPAIGNOUTPUT']._serialized_start=625
  _globals['_DELETECAMPAIGNOUTPUT']._serialized_end=647
  _globals['_DESCRIBECAMPAIGNINPUT']._serialized_start=649
  _globals['_DESCRIBECAMPAIGNINPUT']._serialized_end=744
  _globals['_DESCRIBECAMPAIGNOUTPUT']._serialized_start=746
  _globals['_DESCRIBECAMPAIGNOUTPUT']._serialized_end=817
  _globals['_LISTCAMPAIGNSINPUT']._serialized_start=820
  _globals['_LISTCAMPAIGNSINPUT']._serialized_end=1245
  _globals['_LISTCAMPAIGNSINPUT_FILTER']._serialized_start=1121
  _globals['_LISTCAMPAIGNSINPUT_FILTER']._serialized_end=1221
  _globals['_LISTCAMPAIGNSINPUT_SORT']._serialized_start=1223
  _globals['_LISTCAMPAIGNSINPUT_SORT']._serialized_end=1245
  _globals['_LISTCAMPAIGNSOUTPUT']._serialized_start=1247
  _globals['_LISTCAMPAIGNSOUTPUT']._serialized_end=1327
  _globals['_TESTCAMPAIGNINPUT']._serialized_start=1330
  _globals['_TESTCAMPAIGNINPUT']._serialized_end=1545
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_TESTCAMPAIGNOUTPUT']._serialized_start=1547
  _globals['_TESTCAMPAIGNOUTPUT']._serialized_end=1567
  _globals['_SENDCAMPAIGNINPUT']._serialized_start=1569
  _globals['_SENDCAMPAIGNINPUT']._serialized_end=1631
  _globals['_SENDCAMPAIGNOUTPUT']._serialized_start=1633
  _globals['_SENDCAMPAIGNOUTPUT']._serialized_end=1653
  _globals['_TRANSLATECAMPAIGNINPUT']._serialized_start=1656
  _globals['_TRANSLATECAMPAIGNINPUT']._serialized_end=1784
  _globals['_TRANSLATECAMPAIGNOUTPUT']._serialized_start=1786
  _globals['_TRANSLATECAMPAIGNOUTPUT']._serialized_end=1827
  _globals['_CREATETRANSLATIONINPUT']._serialized_start=1829
  _globals['_CREATETRANSLATIONINPUT']._serialized_end=1936
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_start=1938
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_end=1987
  _globals['_UPDATETRANSLATIONINPUT']._serialized_start=1990
  _globals['_UPDATETRANSLATIONINPUT']._serialized_end=2171
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_start=2173
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_end=2198
  _globals['_DELETETRANSLATIONINPUT']._serialized_start=2200
  _globals['_DELETETRANSLATIONINPUT']._serialized_end=2269
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_start=2271
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_end=2296
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_start=2298
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_end=2369
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_start=2371
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_end=2460
  _globals['_LISTTRANSLATIONSINPUT']._serialized_start=2463
  _globals['_LISTTRANSLATIONSINPUT']._serialized_end=2707
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_start=2605
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_end=2707
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_start=2709
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_end=2804
  _globals['_CREATERECIPIENTINPUT']._serialized_start=2807
  _globals['_CREATERECIPIENTINPUT']._serialized_end=2997
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_CREATERECIPIENTOUTPUT']._serialized_start=2999
  _globals['_CREATERECIPIENTOUTPUT']._serialized_end=3044
  _globals['_IMPORTRECIPIENTINPUT']._serialized_start=3047
  _globals['_IMPORTRECIPIENTINPUT']._serialized_end=3293
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_start=3295
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_end=3318
  _globals['_DELETERECIPIENTINPUT']._serialized_start=3320
  _globals['_DELETERECIPIENTINPUT']._serialized_end=3385
  _globals['_DELETERECIPIENTOUTPUT']._serialized_start=3387
  _globals['_DELETERECIPIENTOUTPUT']._serialized_end=3410
  _globals['_LISTRECIPIENTSINPUT']._serialized_start=3413
  _globals['_LISTRECIPIENTSINPUT']._serialized_end=3705
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_start=3552
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_end=3705
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_start=3707
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_end=3789
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_start=3791
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_end=3858
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_start=3860
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_end=3934
  _globals['_CAMPAIGNSERVICE']._serialized_start=3937
  _globals['_CAMPAIGNSERVICE']._serialized_end=7462
# @@protoc_insertion_point(module_scope)
