# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/message_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/message_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_pb2 as eolymp_dot_discussion_dot_message__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/discussion/message_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/discussion/message.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x01\n\x13MessageChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12*\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12)\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x0e\n\x06reason\x18\x03 \x01(\t\"l\n\x14\x44\x65scribeMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\"D\n\x15\x44\x65scribeMessageOutput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\xe5\x05\n\x11ListMessagesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x04sort\x18\x32 \x01(\x0e\x32-.eolymp.discussion.ListMessagesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.discussion.ListMessagesInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\x1a\x80\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08reply_to\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tthread_id\x18\x05 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x33\n\nvote_count\x18\x06 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x34\n\x0breply_count\x18\x07 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x38\n\tposted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"G\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tPOSTED_AT\x10\x01\x12\x0e\n\nVOTE_COUNT\x10\x02\x12\x0f\n\x0bREPLY_COUNT\x10\x03\"N\n\x12ListMessagesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.discussion.Message\"Q\n\x10PostMessageInput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x10\n\x08reply_to\x18\x02 \x01(\t\"\'\n\x11PostMessageOutput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"U\n\x12UpdateMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\x15\n\x13UpdateMessageOutput\"8\n\x12\x44\x65leteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteMessageOutput\"4\n\x10VoteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"\'\n\x11VoteMessageOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"-\n\x17ListMessageChangesInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\xd0\x01\n\x18ListMessageChangesOutput\x12\x43\n\x07history\x18\x01 \x03(\x0b\x32\x32.eolymp.discussion.ListMessageChangesOutput.Record\x1ao\n\x06Record\x12\x10\n\x08revision\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content2\xd7\t\n\x0eMessageService\x12\xb3\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"M\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x18\x12\x16/messages/{message_id}\x12\x9c\x01\n\x0cListMessages\x12$.eolymp.discussion.ListMessagesInput\x1a%.eolymp.discussion.ListMessagesOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x0b\x12\t/messages\x12\x9a\x01\n\x0bPostMessage\x12#.eolymp.discussion.PostMessageInput\x1a$.eolymp.discussion.PostMessageOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x0b\"\t/messages\x12\xad\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/messages/{message_id}\x12\xad\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18*\x16/messages/{message_id}\x12\xac\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/messages/{message_id}/vote\x12\xc3\x01\n\x12ListMessageChanges\x12*.eolymp.discussion.ListMessageChangesInput\x1a+.eolymp.discussion.ListMessageChangesOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02 \x12\x1e/messages/{message_id}/changesB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.message_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_MESSAGESERVICE'].methods_by_name['DescribeMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['DescribeMessage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\030\022\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessages']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessages']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\013\022\t/messages'
  _globals['_MESSAGESERVICE'].methods_by_name['PostMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['PostMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\013\"\t/messages'
  _globals['_MESSAGESERVICE'].methods_by_name['UpdateMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['UpdateMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030\032\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['DeleteMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['DeleteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030*\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['VoteMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['VoteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\035\"\033/messages/{message_id}/vote'
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessageChanges']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessageChanges']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002 \022\036/messages/{message_id}/changes'
  _globals['_MESSAGECHANGEDEVENT']._serialized_start=323
  _globals['_MESSAGECHANGEDEVENT']._serialized_end=462
  _globals['_DESCRIBEMESSAGEINPUT']._serialized_start=464
  _globals['_DESCRIBEMESSAGEINPUT']._serialized_end=572
  _globals['_DESCRIBEMESSAGEOUTPUT']._serialized_start=574
  _globals['_DESCRIBEMESSAGEOUTPUT']._serialized_end=642
  _globals['_LISTMESSAGESINPUT']._serialized_start=645
  _globals['_LISTMESSAGESINPUT']._serialized_end=1386
  _globals['_LISTMESSAGESINPUT_FILTER']._serialized_start=929
  _globals['_LISTMESSAGESINPUT_FILTER']._serialized_end=1313
  _globals['_LISTMESSAGESINPUT_SORTABLE']._serialized_start=1315
  _globals['_LISTMESSAGESINPUT_SORTABLE']._serialized_end=1386
  _globals['_LISTMESSAGESOUTPUT']._serialized_start=1388
  _globals['_LISTMESSAGESOUTPUT']._serialized_end=1466
  _globals['_POSTMESSAGEINPUT']._serialized_start=1468
  _globals['_POSTMESSAGEINPUT']._serialized_end=1549
  _globals['_POSTMESSAGEOUTPUT']._serialized_start=1551
  _globals['_POSTMESSAGEOUTPUT']._serialized_end=1590
  _globals['_UPDATEMESSAGEINPUT']._serialized_start=1592
  _globals['_UPDATEMESSAGEINPUT']._serialized_end=1677
  _globals['_UPDATEMESSAGEOUTPUT']._serialized_start=1679
  _globals['_UPDATEMESSAGEOUTPUT']._serialized_end=1700
  _globals['_DELETEMESSAGEINPUT']._serialized_start=1702
  _globals['_DELETEMESSAGEINPUT']._serialized_end=1758
  _globals['_DELETEMESSAGEOUTPUT']._serialized_start=1760
  _globals['_DELETEMESSAGEOUTPUT']._serialized_end=1781
  _globals['_VOTEMESSAGEINPUT']._serialized_start=1783
  _globals['_VOTEMESSAGEINPUT']._serialized_end=1835
  _globals['_VOTEMESSAGEOUTPUT']._serialized_start=1837
  _globals['_VOTEMESSAGEOUTPUT']._serialized_end=1876
  _globals['_LISTMESSAGECHANGESINPUT']._serialized_start=1878
  _globals['_LISTMESSAGECHANGESINPUT']._serialized_end=1923
  _globals['_LISTMESSAGECHANGESOUTPUT']._serialized_start=1926
  _globals['_LISTMESSAGECHANGESOUTPUT']._serialized_end=2134
  _globals['_LISTMESSAGECHANGESOUTPUT_RECORD']._serialized_start=2023
  _globals['_LISTMESSAGECHANGESOUTPUT_RECORD']._serialized_end=2134
  _globals['_MESSAGESERVICE']._serialized_start=2137
  _globals['_MESSAGESERVICE']._serialized_end=3376
# @@protoc_insertion_point(module_scope)
