# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/ticket_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/ticket_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.judge import ticket_reply_pb2 as eolymp_dot_judge_dot_ticket__reply__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/judge/ticket_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a\x1f\x65olymp/judge/ticket_reply.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"n\n\x12TicketChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"o\n\x11ReplyChangedEvent\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12#\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\x12\"\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Reply\"s\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12$\n\x07message\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x13\n\x0braw_message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\xad\x01\n\x11UpdateTicketInput\x12\x34\n\x05patch\x18\x03 \x03(\x0e\x32%.eolymp.judge.UpdateTicketInput.Patch\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\")\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06STATUS\x10\x01\x12\x0b\n\x07SUBJECT\x10\x02\"\x14\n\x12UpdateTicketOutput\"g\n\x0fReadTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x12\n\x10ReadTicketOutput\":\n\x11\x44\x65leteTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"h\n\x13\x44\x65scribeTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\xc7\x05\n\x10ListTicketsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x12\x31\n\x04sort\x18\x32 \x01(\x0e\x32#.eolymp.judge.ListTicketsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\x1a\x9a\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06status\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"&\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\x12\x0e\n\nUPDATED_AT\x10\x01\"a\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"\x82\x01\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x07message\x18\n \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x35\n\x10\x63hange_status_to\x18\x14 \x01(\x0e\x32\x1b.eolymp.judge.Ticket.Status\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"Q\n\x10WatchTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"9\n\x11WatchTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"v\n\x11WatchTicketsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"\xb4\x01\n\x12WatchTicketsOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchTicketsOutput.Event\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"@\n\x17WatchTicketSummaryInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"J\n\x18WatchTicketSummaryOutput\x12\x14\n\x0cunread_count\x18\x03 \x01(\r\x12\x18\n\x10unresolved_count\x18\x04 \x01(\r\"n\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"d\n\x12\x44\x65scribeReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"9\n\x13\x44\x65scribeReplyOutput\x12\"\n\x05reply\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Reply\"7\n\x10\x44\x65leteReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"]\n\x10UpdateReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x13\n\x11UpdateReplyOutput\"a\n\x11WatchRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"\xb2\x01\n\x12WatchRepliesOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchRepliesOutput.Event\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x32\xc9\x11\n\rTicketService\x12\x93\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\n\"\x08/tickets\x12\x99\x01\n\x0cUpdateTicket\x12\x1f.eolymp.judge.UpdateTicketInput\x1a .eolymp.judge.UpdateTicketOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x16\"\x14/tickets/{ticket_id}\x12\x97\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1b\"\x19/tickets/{ticket_id}/read\x12\x99\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x16*\x14/tickets/{ticket_id}\x12\x9e\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x16\x12\x14/tickets/{ticket_id}\x12\x89\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\n\x12\x08/tickets\x12\xa4\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x1e\"\x1c/tickets/{ticket_id}/replies\x12l\n\x0bWatchTicket\x12\x1e.eolymp.judge.WatchTicketInput\x1a\x1f.eolymp.judge.WatchTicketOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12o\n\x0cWatchTickets\x12\x1f.eolymp.judge.WatchTicketsInput\x1a .eolymp.judge.WatchTicketsOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x81\x01\n\x12WatchTicketSummary\x12%.eolymp.judge.WatchTicketSummaryInput\x1a&.eolymp.judge.WatchTicketSummaryOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x9d\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/tickets/{ticket_id}/replies\x12\xaf\x01\n\rDescribeReply\x12 .eolymp.judge.DescribeReplyInput\x1a!.eolymp.judge.DescribeReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\x12\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)*\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\"\'/tickets/{ticket_id}/replies/{reply_id}\x12o\n\x0cWatchReplies\x12\x1f.eolymp.judge.WatchRepliesInput\x1a .eolymp.judge.WatchRepliesOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.ticket_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\n\"\010/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\026\"\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ReadTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ReadTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\033\"\031/tickets/{ticket_id}/read'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\026*\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\026\022\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\n\022\010/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['ReplyTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ReplyTicket']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\036\"\034/tickets/{ticket_id}/replies'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicketSummary']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicketSummary']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['ListReplies']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListReplies']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\036\022\034/tickets/{ticket_id}/replies'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\022\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)*\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\"\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['WatchReplies']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETCHANGEDEVENT']._serialized_start=338
  _globals['_TICKETCHANGEDEVENT']._serialized_end=448
  _globals['_REPLYCHANGEDEVENT']._serialized_start=450
  _globals['_REPLYCHANGEDEVENT']._serialized_end=561
  _globals['_CREATETICKETINPUT']._serialized_start=563
  _globals['_CREATETICKETINPUT']._serialized_end=678
  _globals['_CREATETICKETOUTPUT']._serialized_start=680
  _globals['_CREATETICKETOUTPUT']._serialized_end=719
  _globals['_UPDATETICKETINPUT']._serialized_start=722
  _globals['_UPDATETICKETINPUT']._serialized_end=895
  _globals['_UPDATETICKETINPUT_PATCH']._serialized_start=854
  _globals['_UPDATETICKETINPUT_PATCH']._serialized_end=895
  _globals['_UPDATETICKETOUTPUT']._serialized_start=897
  _globals['_UPDATETICKETOUTPUT']._serialized_end=917
  _globals['_READTICKETINPUT']._serialized_start=919
  _globals['_READTICKETINPUT']._serialized_end=1022
  _globals['_READTICKETOUTPUT']._serialized_start=1024
  _globals['_READTICKETOUTPUT']._serialized_end=1042
  _globals['_DELETETICKETINPUT']._serialized_start=1044
  _globals['_DELETETICKETINPUT']._serialized_end=1102
  _globals['_DELETETICKETOUTPUT']._serialized_start=1104
  _globals['_DELETETICKETOUTPUT']._serialized_end=1124
  _globals['_DESCRIBETICKETINPUT']._serialized_start=1126
  _globals['_DESCRIBETICKETINPUT']._serialized_end=1230
  _globals['_DESCRIBETICKETOUTPUT']._serialized_start=1232
  _globals['_DESCRIBETICKETOUTPUT']._serialized_end=1292
  _globals['_LISTTICKETSINPUT']._serialized_start=1295
  _globals['_LISTTICKETSINPUT']._serialized_end=2006
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_start=1556
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_end=1966
  _globals['_LISTTICKETSINPUT_SORT']._serialized_start=1968
  _globals['_LISTTICKETSINPUT_SORT']._serialized_end=2006
  _globals['_LISTTICKETSOUTPUT']._serialized_start=2008
  _globals['_LISTTICKETSOUTPUT']._serialized_end=2105
  _globals['_REPLYTICKETINPUT']._serialized_start=2108
  _globals['_REPLYTICKETINPUT']._serialized_end=2238
  _globals['_REPLYTICKETOUTPUT']._serialized_start=2240
  _globals['_REPLYTICKETOUTPUT']._serialized_end=2277
  _globals['_WATCHTICKETINPUT']._serialized_start=2279
  _globals['_WATCHTICKETINPUT']._serialized_end=2360
  _globals['_WATCHTICKETOUTPUT']._serialized_start=2362
  _globals['_WATCHTICKETOUTPUT']._serialized_end=2419
  _globals['_WATCHTICKETSINPUT']._serialized_start=2421
  _globals['_WATCHTICKETSINPUT']._serialized_end=2539
  _globals['_WATCHTICKETSOUTPUT']._serialized_start=2542
  _globals['_WATCHTICKETSOUTPUT']._serialized_end=2722
  _globals['_WATCHTICKETSOUTPUT_EVENT']._serialized_start=2657
  _globals['_WATCHTICKETSOUTPUT_EVENT']._serialized_end=2722
  _globals['_WATCHTICKETSUMMARYINPUT']._serialized_start=2724
  _globals['_WATCHTICKETSUMMARYINPUT']._serialized_end=2788
  _globals['_WATCHTICKETSUMMARYOUTPUT']._serialized_start=2790
  _globals['_WATCHTICKETSUMMARYOUTPUT']._serialized_end=2864
  _globals['_LISTREPLIESINPUT']._serialized_start=2866
  _globals['_LISTREPLIESINPUT']._serialized_end=2976
  _globals['_LISTREPLIESOUTPUT']._serialized_start=2978
  _globals['_LISTREPLIESOUTPUT']._serialized_end=3048
  _globals['_DESCRIBEREPLYINPUT']._serialized_start=3050
  _globals['_DESCRIBEREPLYINPUT']._serialized_end=3150
  _globals['_DESCRIBEREPLYOUTPUT']._serialized_start=3152
  _globals['_DESCRIBEREPLYOUTPUT']._serialized_end=3209
  _globals['_DELETEREPLYINPUT']._serialized_start=3211
  _globals['_DELETEREPLYINPUT']._serialized_end=3266
  _globals['_DELETEREPLYOUTPUT']._serialized_start=3268
  _globals['_DELETEREPLYOUTPUT']._serialized_end=3287
  _globals['_UPDATEREPLYINPUT']._serialized_start=3289
  _globals['_UPDATEREPLYINPUT']._serialized_end=3382
  _globals['_UPDATEREPLYOUTPUT']._serialized_start=3384
  _globals['_UPDATEREPLYOUTPUT']._serialized_end=3403
  _globals['_WATCHREPLIESINPUT']._serialized_start=3405
  _globals['_WATCHREPLIESINPUT']._serialized_end=3502
  _globals['_WATCHREPLIESOUTPUT']._serialized_start=3505
  _globals['_WATCHREPLIESOUTPUT']._serialized_end=3683
  _globals['_WATCHREPLIESOUTPUT_EVENT']._serialized_start=2657
  _globals['_WATCHREPLIESOUTPUT_EVENT']._serialized_end=2722
  _globals['_TICKETSERVICE']._serialized_start=3686
  _globals['_TICKETSERVICE']._serialized_end=5935
# @@protoc_insertion_point(module_scope)
