# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/playground/playground.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/playground/playground.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/playground/playground.proto\x12\x11\x65olymp.playground\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/playground/run.proto\"e\n\x0e\x43reateRunInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x64 \x01(\t\x12\x14\n\ninput_data\x18\x65 \x01(\x0cH\x00\x12\x13\n\tinput_ref\x18\x66 \x01(\tH\x00\x42\x07\n\x05input\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x1f\n\rWatchRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"5\n\x0eWatchRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run2\xd4\x03\n\nPlayground\x12\x8c\x01\n\tCreateRun\x12!.eolymp.playground.CreateRunInput\x1a\".eolymp.playground.CreateRunOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\x82\xd3\xe4\x93\x02\x07\"\x05/runs\x12\x9a\x01\n\x0b\x44\x65scribeRun\x12#.eolymp.playground.DescribeRunInput\x1a$.eolymp.playground.DescribeRunOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/runs/{run_id}\x12\x99\x01\n\x08WatchRun\x12 .eolymp.playground.WatchRunInput\x1a!.eolymp.playground.WatchRunOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x16\x12\x14/runs/{run_id}/watch0\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/playground;playgroundb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.playground.playground_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/playground;playground'
  _globals['_PLAYGROUND'].methods_by_name['CreateRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['CreateRun']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\030\212\343\n\024playground:run:write\202\323\344\223\002\007\"\005/runs'
  _globals['_PLAYGROUND'].methods_by_name['DescribeRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['DescribeRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\020\022\016/runs/{run_id}'
  _globals['_PLAYGROUND'].methods_by_name['WatchRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['WatchRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\026\022\024/runs/{run_id}/watch'
  _globals['_CREATERUNINPUT']._serialized_start=185
  _globals['_CREATERUNINPUT']._serialized_end=286
  _globals['_CREATERUNOUTPUT']._serialized_start=288
  _globals['_CREATERUNOUTPUT']._serialized_end=321
  _globals['_DESCRIBERUNINPUT']._serialized_start=323
  _globals['_DESCRIBERUNINPUT']._serialized_end=357
  _globals['_DESCRIBERUNOUTPUT']._serialized_start=359
  _globals['_DESCRIBERUNOUTPUT']._serialized_end=415
  _globals['_WATCHRUNINPUT']._serialized_start=417
  _globals['_WATCHRUNINPUT']._serialized_end=448
  _globals['_WATCHRUNOUTPUT']._serialized_start=450
  _globals['_WATCHRUNOUTPUT']._serialized_end=503
  _globals['_PLAYGROUND']._serialized_start=506
  _globals['_PLAYGROUND']._serialized_end=974
# @@protoc_insertion_point(module_scope)
